import type { BoxProps } from "@mui/material/Box";
import type { SketchPickerStylesProps } from "react-color/lib/components/sketch/Sketch";
import type { ButtonProps } from "../Button/index.js";
export declare const colorInputClasses: {
    root: string;
    pickerButton: string;
    pickerButtonBackground: string;
    pickerButtonColor: string;
    popoverPaper: string;
};
export interface SketchColorPreset {
    /**
     * A valid hex string color.
     */
    color: string;
    /**
     * A title representing the color preset.
     */
    title: string;
}
export type ColorInputClassKey = keyof typeof colorInputClasses;
export type ColorInputClasses = Record<ColorInputClassKey, string>;
export interface ColorInputProps extends Omit<BoxProps, "onChange"> {
    /**
     * Optional button props
     */
    ButtonProps?: ButtonProps;
    /**
     * Additional CSS classes to be applied to the component.
     */
    classes?: Partial<ColorInputClasses>;
    /**
     * If `true`, the input will be disabled.
     */
    disabled?: boolean;
    /**
     * Will be called every time the value changes.
     */
    onChange?: (value: string) => void;
    /**
     * Array of hex strings or color preset objects or a combination of both to
     * be shown in the color swatch area.
     */
    presetColors?: (string | SketchColorPreset)[];
    /**
     * Style overrides for the react-color SketchPicker.
     */
    sketchPickerStyle?: Partial<SketchPickerStylesProps>;
    /**
     * The color value. This can be any valid CSS color value such as: `blue`,
     * `#0000FF`, `rgb(0, 0, 255)`, `rgba(0, 0, 255, 0.5)`
     */
    value?: string;
}
export declare const ColorInput: import("react").ForwardRefExoticComponent<Omit<ColorInputProps, "ref"> & import("react").RefAttributes<HTMLDivElement>>;
export default ColorInput;
