import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import Box from "@mui/material/Box";
import { useFormControl } from "@mui/material/FormControl";
import clsx from "clsx";
import { forwardRef, useState } from "react";
import { SketchPicker } from "react-color";
import Button from "../Button/index.js";
import Popover from "../Popover/index.js";
import { mergeStyles, styled, useTheme } from "../styles/index.js";
import { parse as parseColor } from "../utils/color.js";
const PREFIX = "GcxColorInput";
export const colorInputClasses = {
    root: `${PREFIX}-root`,
    pickerButton: `${PREFIX}-pickerButton`,
    pickerButtonBackground: `${PREFIX}-pickerButtonBackground`,
    pickerButtonColor: `${PREFIX}-pickerButtonColor`,
    popoverPaper: `${PREFIX}-popoverPaper`,
};
const defaultRgbColor = {
    r: 255,
    g: 255,
    b: 255,
    alpha: 1,
};
const defaultColors = [
    "#1479CB",
    "#008A00",
    "#5B7F39",
    "#D43900",
    "#8667AD",
    "#C9493C",
    "#0D8387",
    "#D025B9",
];
const Root = styled(Box)(({ theme: { palette, shape, typography } }) => ({
    [`& .${colorInputClasses.pickerButton}`]: {
        border: "none",
        margin: 0,
        // Reset button's min-width.
        minWidth: "unset",
        padding: typography.pxToRem(8),
    },
    [`& .${colorInputClasses.pickerButtonBackground}`]: {
        // Background: https://css-tricks.com/stripes-css/
        background: `repeating-linear-gradient(
                            135deg,
                            ${palette.grey[600]},
                            ${palette.grey[600]} 10px,
                            ${palette.common.white} 10px,
                            ${palette.common.white} 20px
                        )`,
    },
    [`& .${colorInputClasses.pickerButtonColor}`]: {
        height: typography.pxToRem(20),
        width: typography.pxToRem(76),
    },
    [`& .${colorInputClasses.popoverPaper}`]: {
        padding: 0,
        "& .sketch-picker input": {
            backgroundColor: "transparent",
            borderRadius: shape.borderRadius,
            color: palette.text.primary,
            textAlign: "center",
        },
        "& .sketch-picker span": {
            color: `${palette.text.primary} !important`,
        },
    },
}));
export const ColorInput = forwardRef(({ "aria-labelledby": ariaLabelledBy, "aria-describedby": ariaDescribedBy, ButtonProps, className, classes: classesProp, disabled, presetColors, onChange, value: unsanitizedValue, sketchPickerStyle = {}, ...others }, ref) => {
    const theme = useTheme();
    const [buttonEl, setButtonEl] = useState();
    const handleColorPopoverOpen = (event) => setButtonEl(event.currentTarget);
    const handleColorPopoverClose = () => setButtonEl(undefined);
    const handleColorPickerChangeComplete = (newColor) => {
        const validatedColor = parseColor(newColor.rgb);
        if (validatedColor) {
            onChange?.(validatedColor.rgb().string());
        }
    };
    // Careful. `useFormControl` can return undefined.
    // See https://github.com/mui-org/material-ui/pull/20278.
    const muiFormControl = useFormControl();
    // `RGB(0,0,0)` will fail, we should instead convert to `rgb(0,0,0)`
    const value = unsanitizedValue?.toLowerCase();
    // Color allows us to easily convert between different color types
    const color = parseColor(value);
    // The rgb object will be used for passing values to the color picker component
    const rgb = color ? color.rgb().object() : defaultRgbColor;
    const classes = mergeStyles(colorInputClasses, classesProp);
    return (_jsxs(Root, { className: clsx(classes.root, className), ...others, ref: ref, children: [_jsx(Button, { ...ButtonProps, "aria-labelledby": ariaLabelledBy, "aria-describedby": ariaDescribedBy, disabled: ButtonProps?.disabled ?? disabled ?? muiFormControl?.disabled, className: clsx(classes.pickerButton, ButtonProps?.className), "data-test": "ColorInput-picker-button", onClick: event => {
                    handleColorPopoverOpen(event);
                    ButtonProps?.onClick?.(event);
                }, children: _jsx("div", { className: classes.pickerButtonBackground, children: _jsx("div", { className: classes.pickerButtonColor, "data-test": "ColorInput-picker-button-color", style: {
                            // The rgb CSS string will be used for styling the color picker button
                            background: color ? color.rgb().string() : "transparent",
                        } }) }) }), _jsx(Popover, { anchorEl: buttonEl, open: !!buttonEl, anchorOrigin: {
                    vertical: "bottom",
                    horizontal: "left",
                }, transformOrigin: {
                    vertical: "top",
                    horizontal: "left",
                }, onClose: handleColorPopoverClose, PaperProps: {
                    classes: { root: classes.popoverPaper },
                    // Workaround for type error. This is valid and gets passed through.
                    [`${"data-test"}`]: "ColorInput-color-picker",
                }, children: _jsx(SketchPicker
                // The color object that the picker expects uses key `a` instead of `alpha`
                , { 
                    // The color object that the picker expects uses key `a` instead of `alpha`
                    color: {
                        r: rgb.r,
                        g: rgb.g,
                        b: rgb.b,
                        a: rgb.alpha,
                    }, onChangeComplete: handleColorPickerChangeComplete, presetColors: presetColors ?? defaultColors, styles: {
                        default: {
                            picker: {
                                background: theme.palette.background.paper,
                            },
                            ...sketchPickerStyle,
                        },
                    } }) })] }));
});
export default ColorInput;
