import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import clsx from "clsx";
import { forwardRef, useRef, useState } from "react";
import Button from "../Button/index.js";
import Input from "../Input/index.js";
import Stack from "../Stack/index.js";
import Tooltip from "../Tooltip/index.js";
import CopyIcon from "../icons/Copy.js";
import { mergeStyles, styled } from "../styles/index.js";
import { mergeRefs } from "../utils/react.js";
const PREFIX = "GcxCopyableText";
export const copyableTextClasses = {
    root: `${PREFIX}-root`,
    input: `${PREFIX}-input`,
    inputRoot: `${PREFIX}-inputRoot`,
    iconButton: `${PREFIX}-iconButton`,
};
const StyledStack = styled(Stack)(({ theme: { typography } }) => ({
    [`& .${copyableTextClasses.input}`]: {
        width: "100%",
    },
    [`& .${copyableTextClasses.inputRoot}`]: {
        flex: 1,
        borderTopRightRadius: 0,
        borderBottomRightRadius: 0,
    },
    [`& .${copyableTextClasses.iconButton}`]: {
        minWidth: "unset",
        width: typography.pxToRem(16),
        borderLeft: "none",
        margin: 0,
        borderTopLeftRadius: 0,
        borderBottomLeftRadius: 0,
    },
}));
const CopyableText = forwardRef((props, ref) => {
    const localRef = useRef();
    const [open, setOpen] = useState(false);
    const [showClickedMessage, setShowClickedMessage] = useState(false);
    const handleTooltipClose = () => setOpen(false);
    const handleTooltipOpen = () => {
        // Because this is hooked up internally to a mouseEnter event in
        // Tooltip, this can get fired multiple times when the user is moving
        // their mouse within the button. showClickedMessage should get set to
        // false when the user is re-entering the button, otherwise it should
        // keep its value.
        setOpen(true);
        setShowClickedMessage(open && showClickedMessage);
    };
    const handleMouseDown = (e) => {
        // We need to call preventDefault() because otherwise the mousedown will
        // fire a Blur event which triggers Tooltip's onClose which will close
        // the tooltip (as per the logic in handleTooltipClose()). As we dont
        // want the tooltip to close when the button is clicked, we need to stop
        // the propagation of this event.
        e.preventDefault();
    };
    const handleCopyUrl = async (e) => {
        if (!localRef.current) {
            return;
        }
        await navigator.clipboard.writeText(value ?? "");
        setShowClickedMessage(true);
    };
    const { classes: classesProp, className, InputProps = {}, tooltipCopiedText, tooltipCopyText, value, ...other } = props;
    const { classes: inputPropsClasses = {}, inputProps, ...otherInputProps } = InputProps;
    const { root, input, ...otherClasses } = inputPropsClasses;
    const classes = mergeStyles(copyableTextClasses, classesProp);
    return (_jsxs(StyledStack, { direction: "row", className: clsx(classes.root, className), ...other, children: [_jsx(Input, { classes: {
                    root: clsx(classes.inputRoot, root),
                    input: clsx(classes.input, input),
                    ...otherClasses,
                }, inputProps: {
                    readOnly: true,
                    "data-test": "CopyableText-Input",
                    ...inputProps,
                }, inputRef: mergeRefs(ref, localRef), value: value ?? "", "data-test": "CopyableText-Input-Wrapper", ...otherInputProps }), _jsx(Tooltip, { "data-test": "CopyableText-Tooltip", open: open, onOpen: handleTooltipOpen, onClose: handleTooltipClose, title: showClickedMessage ? tooltipCopiedText : tooltipCopyText, placement: "bottom", children: _jsx(Button, { className: classes.iconButton, "data-test": "CopyableText-IconButton", disabled: !value, onClick: handleCopyUrl, onMouseDown: handleMouseDown, children: _jsx(CopyIcon, {}) }) })] }));
});
CopyableText.displayName = "CopyableText";
export default CopyableText;
