import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import MUIFormLabel, { formLabelClasses as muiFormLabelClasses } from "@mui/material/FormLabel";
import clsx from "clsx";
import { forwardRef } from "react";
import Box from "../Box/index.js";
import { useFormControl } from "../FormControl/index.js";
import ErrorIcon from "../icons/Error.js";
import { mergeStyles, styled } from "../styles/index.js";
const PREFIX = "GcxFormLabel";
const gcxFormLabelClasses = {
    errorIcon: `${PREFIX}-errorIcon`,
    errorIconBackground: `${PREFIX}-errorIconBackground`,
};
// MUST be the first export, since some of the exports are overridden below.
export * from "@mui/material/FormLabel";
export const formLabelClasses = {
    ...muiFormLabelClasses,
    ...gcxFormLabelClasses,
};
const StyledMUIFormLabel = styled(MUIFormLabel)(({ theme: { spacing, palette } }) => ({
    [`& .${formLabelClasses.errorIcon}`]: {
        fontSize: "0.875em",
    },
}));
export const FormLabel = forwardRef((props, ref) => {
    const { children, classes, className, error: errorProp, ...other } = props;
    // Careful. `useFormControl` can return undefined.
    // See https://github.com/mui-org/material-ui/pull/20278.
    const muiFormControl = useFormControl();
    const error = errorProp ?? muiFormControl?.error;
    const { errorIcon: errorIconClass, errorIconBackground: errorIconBackgroundClass, ...otherClasses } = mergeStyles(gcxFormLabelClasses, classes);
    return (_jsxs(StyledMUIFormLabel, { error: error, className: clsx("GcxFormLabel", className), ...other, classes: otherClasses, ref: ref, children: [error && (_jsx(Box, { className: errorIconBackgroundClass, component: "span", children: _jsx(ErrorIcon, { className: errorIconClass, "data-test": "FormLabel-ErrorIcon" }) })), children] }));
});
export default FormLabel;
