import { type ReactNode } from "react";
import type { AutocompleteChangeDetails, AutocompleteChangeReason, AutocompleteProps } from "../Autocomplete";
import type { ChipTypeMap } from "../Chip";
import type { FormControlProps } from "../FormControl/index.js";
import { type FormHelperTextProps } from "../FormHelperText/index.js";
export type FormLabelAutocompleteFieldProps<T, Multiple extends boolean | undefined, DisableClearable extends boolean | undefined, FreeSolo extends boolean | undefined, ChipComponent extends React.ElementType = ChipTypeMap["defaultComponent"]> = Omit<FormControlProps, "defaultValue" | "onBlur" | "onChange" | "onFocus" | "value"> & {
    /**
     * The label content.
     */
    label?: React.ReactNode;
    /**
     * Props applied to the
     * [`FormHelperText`](/material-ui/api/form-helper-text/) element.
     */
    FormHelperTextProps?: Partial<FormHelperTextProps>;
    /**
     * The helper text content.
     */
    helperText?: React.ReactNode;
    defaultValue?: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["defaultValue"];
    disableClearable: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["disableClearable"];
    disabled?: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["disabled"];
    filterOptions?: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["filterOptions"];
    getOptionLabel: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["getOptionLabel"];
    onBlur?: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["onBlur"];
    onChange?: (event: React.SyntheticEvent, newValue: T | NonNullable<string | T> | (string | T)[] | null, reason: AutocompleteChangeReason, details: AutocompleteChangeDetails<T> | undefined) => void;
    onFocus?: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["onFocus"];
    options: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["options"];
    value: AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>["value"];
    AutocompleteProps?: Partial<AutocompleteProps<T, Multiple, DisableClearable, FreeSolo, ChipComponent>>;
};
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel. Also allows
 * for inline help.
 */
declare const FormLabelAutocompleteField: <TValue>(props: FormLabelAutocompleteFieldProps<TValue, boolean | undefined, boolean | undefined, boolean | undefined>) => ReactNode;
export default FormLabelAutocompleteField;
