import type { TextFieldProps } from "@mui/material/TextField";
import { type FC } from "react";
import type { FormControlProps } from "../FormControl/index.js";
import { type FormHelperTextProps } from "../FormHelperText/index.js";
import { type NumberInputProps } from "../NumberInput/index.js";
/**
 * Properties for FormLabelNumberField.
 */
export type FormLabelNumberFieldProps = Omit<TextFieldProps, "aria-label" | "value" | "onChange" | "InputProps" | "select" | "nativeSelect" | "multiline" | "minRows" | "maxRows" | "SelectProps" | "rows" | "type" | "title" | "onError" | "FormHelperTextProps"> & Pick<FormControlProps, "inlineHelpContent" | "inlineHelpUrl"> & NumberInputProps & {
    InputProps?: Omit<NumberInputProps, "id" | "ref">;
    NumberInputComponent?: FC<NumberInputProps>;
    /**
     * A label to display as helpText when the number input value is out of
     * range, relative to the min and max properties.
     */
    numberOutOfRangeErrorText?: string;
    /**
     * A label to display as helpText when the number input value is invalid
     * (ie. NaN).
     */
    invalidNumberErrorText?: string;
    /**
     * A label to display as helpText when the number input value has more
     * than the configured maxDecimalPlaces.
     */
    maxDecimalPlacesErrorText?: string;
    /**
     * The FormHelperTextProps found on the TextFieldProps are deprecated
     * and will be removed in MUI 7
     */
    FormHelperTextProps?: Partial<FormHelperTextProps>;
};
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel, and uses
 * NumberInput instead of a normal input.
 */
declare const FormLabelNumberField: import("react").ForwardRefExoticComponent<Omit<FormLabelNumberFieldProps, "ref"> & import("react").RefAttributes<HTMLDivElement>>;
export default FormLabelNumberField;
