import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useContext, useState } from "react";
import { forwardRef } from "react";
import FormControl from "../FormControl/index.js";
import FormHelperText, {} from "../FormHelperText/index.js";
import FormLabel from "../FormLabel/index.js";
import { NumberFormatContext } from "../NumberFormatContext/NumberFormatContext.js";
import { DEFAULT_DECIMAL_PLACES, } from "../NumberInput/index.js";
import NumberInput from "../NumberInput/index.js";
import { useId } from "../utils/react.js";
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel, and uses
 * NumberInput instead of a normal input.
 */
const FormLabelNumberField = forwardRef((props, ref) => {
    const { autoComplete, autoFocus = false, children, className, defaultValue, FormHelperTextProps, fullWidth = false, helperText, id: idProp, inputProps, InputProps, inputRef, label, name, NumberInputComponent, onBlur, onChange, onFocus, placeholder, value, min, max, numberOutOfRangeErrorText, invalidNumberErrorText, maxDecimalPlacesErrorText, error = false, onError, onErrorEnd, allowUndefined, maxDecimalPlaces = DEFAULT_DECIMAL_PLACES, correctOnBlur = true, ...other } = props;
    const id = useId(idProp);
    const helperTextId = helperText && id ? `${id}-helper-text` : undefined;
    const inputLabelId = label && id ? `${id}-label` : undefined;
    const FormNumberInput = NumberInputComponent ?? NumberInput;
    const { parseNumber } = useContext(NumberFormatContext);
    const [numberError, setNumberError] = useState();
    const handleError = useCallback((numericValue, textValue, errorType) => {
        if (errorType === "out-of-range") {
            setNumberError(numberOutOfRangeErrorText ??
                getNumberErrorText(parseNumber(textValue), min, max));
        }
        else if (errorType === "NaN") {
            setNumberError(invalidNumberErrorText ?? "Value must be a valid number.");
        }
        else if (errorType === "max-decimals") {
            setNumberError(maxDecimalPlacesErrorText ??
                `Value must have at most ${maxDecimalPlaces} decimal places.`);
        }
        onError?.(numericValue, textValue, errorType);
    }, [
        onError,
        max,
        min,
        parseNumber,
        invalidNumberErrorText,
        numberOutOfRangeErrorText,
        maxDecimalPlaces,
        maxDecimalPlacesErrorText,
    ]);
    const handleErrorEnd = useCallback((numericValue, textValue) => {
        setNumberError(undefined);
        onErrorEnd?.(numericValue, textValue);
    }, [onErrorEnd]);
    return (_jsxs(FormControl, { fullWidth: fullWidth, ref: ref, error: error || !!numberError, ...other, children: [label && (_jsx(FormLabel, { htmlFor: id, id: inputLabelId, children: label })), (helperText ?? numberError) && (_jsx(FormHelperText, { ...FormHelperTextProps, id: helperTextId, children: numberError ?? helperText })), _jsx(FormNumberInput
            // All of the properties fron here down to `InputProps` can be overridden by it.
            // Any after that must be controlled by this component itself.
            , { 
                // All of the properties fron here down to `InputProps` can be overridden by it.
                // Any after that must be controlled by this component itself.
                autoComplete: autoComplete, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, defaultValue: defaultValue, fullWidth: fullWidth, name: name, value: value, inputRef: inputRef, onBlur: onBlur, onChange: onChange, onFocus: onFocus, placeholder: placeholder, inputProps: inputProps, error: error, min: min, max: max, allowUndefined: allowUndefined, maxDecimalPlaces: maxDecimalPlaces, correctOnBlur: correctOnBlur, ...InputProps, "aria-describedby": helperTextId, id: id, onError: (numericValue, textValue, errorType) => {
                    InputProps?.onError?.(numericValue, textValue, errorType);
                    handleError(numericValue, textValue, errorType);
                }, onErrorEnd: (numericValue, textValue) => {
                    InputProps?.onErrorEnd?.(numericValue, textValue);
                    handleErrorEnd(numericValue, textValue);
                } })] }));
});
function getNumberErrorText(val, min, max) {
    const hasMax = typeof max === "number" && !isNaN(max);
    const hasMin = typeof min === "number" && !isNaN(min);
    const isBelow = hasMin && val < min;
    const isAbove = hasMax && val > max;
    if (isNaN(val) || (!isAbove && !isBelow)) {
        return undefined;
    }
    else if (hasMin && hasMax) {
        return `Value must be between ${min} and ${max}.`;
    }
    else if (hasMin) {
        return `Value must be at least ${min}.`;
    }
    else if (hasMax) {
        return `Value must not be higher than ${max}.`;
    }
    else {
        return undefined;
    }
}
export default FormLabelNumberField;
