import { type SliderProps } from "@mui/material";
import type { TextFieldProps } from "@mui/material/TextField";
import { type FC } from "react";
import type { FormControlProps } from "../FormControl/index.js";
import { type FormHelperTextProps } from "../FormHelperText/index.js";
import { type ErrorType, type NumberInputProps } from "../NumberInput/index.js";
export type FormLabelSliderFieldProps = Omit<TextFieldProps, "variant" | "Value" | "onChange" | "defaultValue" | "type" | "select" | "multiline" | "minRows" | "maxRows" | "SelectProps" | "rows" | "InputProps" | "inputProps" | "onError" | "FormHelperTextProps"> & Pick<FormControlProps, "inlineHelpContent" | "inlineHelpUrl"> & {
    value?: number;
    onChange?: (value: number) => void;
    SliderProps?: SliderProps;
    NumberInputComponent?: FC<NumberInputProps>;
    InputProps?: Omit<NumberInputProps, "allowUndefined">;
    inputProps?: NumberInputProps["inputProps"];
    defaultValue?: number;
    /**
     * The FormHelperTextProps found on the TextFieldProps are deprecated
     * and will be removed in MUI 7
     */
    FormHelperTextProps?: Partial<FormHelperTextProps>;
    /**
     * A label to display as helpText when the number input value is out of
     * range, relative to the min and max properties.
     */
    numberOutOfRangeErrorText?: string;
    /**
     * A label to display as helpText when the number input value is invalid
     * (ie. NaN).
     */
    invalidNumberErrorText?: string;
    /**
     * A label to display as helpText when the number input value has more
     * than the configured maxDecimalPlaces.
     */
    maxDecimalPlacesErrorText?: string;
    /**
     * Executed when the input moves into an error state.
     */
    onError?: (value: number, textValue: string, type: ErrorType) => void;
    /**
     * Executed when the input moves out of an error state.
     */
    onErrorEnd?: (value: number, textValue: string) => void;
};
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel. Also allows
 * for inline help.
 */
declare const FormLabelSliderField: import("react").ForwardRefExoticComponent<Omit<FormLabelSliderFieldProps, "ref"> & import("react").RefAttributes<HTMLDivElement>>;
export default FormLabelSliderField;
