import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Slider, useTheme } from "@mui/material";
import { Stack } from "@mui/material";
import { forwardRef, useCallback, useContext, useRef, useState } from "react";
import FormControl from "../FormControl/index.js";
import FormHelperText, {} from "../FormHelperText/index.js";
import FormLabel from "../FormLabel/index.js";
import { NumberFormatContext } from "../NumberFormatContext/NumberFormatContext.js";
import NumberInput, { DEFAULT_DECIMAL_PLACES, } from "../NumberInput/index.js";
import { useId } from "../utils/react.js";
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel. Also allows
 * for inline help.
 */
const FormLabelSliderField = forwardRef((props, ref) => {
    const { autoComplete, autoFocus = false, defaultValue, disabled, fullWidth = false, helperText, id: idProp, inputProps, InputProps, inputRef, label, name, onBlur, onChange, onFocus, onKeyDown, onMouseUp, placeholder, slotProps, value, SliderProps, numberOutOfRangeErrorText, invalidNumberErrorText, onError, onErrorEnd, error, maxDecimalPlacesErrorText, NumberInputComponent, FormHelperTextProps, ...other } = props;
    const inputId = `${useId(idProp)}-input`;
    const sliderId = `${useId(idProp)}-slider`;
    const helperTextId = helperText && inputId ? `${inputId}-helper-text` : undefined;
    const inputLabelId = label && inputId ? `${inputId}-label` : undefined;
    const inputReference = useRef();
    const { typography } = useTheme();
    const handleSliderChange = useCallback((event, value) => {
        onChange?.(value);
    }, [onChange]);
    const max = SliderProps?.max ?? InputProps?.max ?? 100;
    const min = SliderProps?.min ?? InputProps?.min ?? 0;
    const { parseNumber } = useContext(NumberFormatContext);
    const [numberError, setNumberError] = useState();
    const maxDecimalPlaces = InputProps?.maxDecimalPlaces ?? DEFAULT_DECIMAL_PLACES;
    const handleError = useCallback((numericValue, textValue, errorType) => {
        if (errorType === "out-of-range") {
            setNumberError(numberOutOfRangeErrorText ??
                getNumberErrorText(parseNumber(textValue), min, max));
        }
        else if (errorType === "NaN") {
            setNumberError(invalidNumberErrorText ?? "Value must be a valid number.");
        }
        else if (errorType === "max-decimals") {
            setNumberError(maxDecimalPlacesErrorText ??
                `Value must have at most ${maxDecimalPlaces} decimal places.`);
        }
        onError?.(numericValue, textValue, errorType);
    }, [
        onError,
        max,
        min,
        parseNumber,
        invalidNumberErrorText,
        numberOutOfRangeErrorText,
        maxDecimalPlaces,
        maxDecimalPlacesErrorText,
    ]);
    const handleErrorEnd = useCallback((numericValue, textValue) => {
        setNumberError(undefined);
        onErrorEnd?.(numericValue, textValue);
    }, [onErrorEnd]);
    const FormNumberInput = NumberInputComponent ?? NumberInput;
    const InputElement = (_jsx(FormNumberInput, { "aria-labelledby": inputLabelId, "aria-describedby": helperTextId, autoComplete: autoComplete, 
        // Disabling this linting rule since the intent is to forward it
        // if it exists rather than set it.
        //
        // eslint-disable-next-line jsx-a11y/no-autofocus
        autoFocus: autoFocus, defaultValue: defaultValue, fullWidth: fullWidth, id: inputId, inputProps: inputProps, inputRef: inputRef ?? inputReference, name: name, onChange: onChange, placeholder: placeholder, value: value, error: error, onError: handleError, onErrorEnd: handleErrorEnd, min, max, ...InputProps, sx: { maxWidth: typography.pxToRem(74), ...InputProps?.sx } }));
    return (_jsxs(FormControl, { fullWidth: fullWidth, ref: ref, disabled: disabled, error: error ?? !!numberError, ...other, children: [label && (_jsx(FormLabel, { htmlFor: inputId, id: inputLabelId, children: label })), (helperText ?? !!numberError) && (_jsx(FormHelperText, { ...FormHelperTextProps, id: helperTextId, children: numberError ?? helperText })), _jsxs(Stack, { direction: "row", spacing: 1, children: [_jsx(Slider, { "aria-describedby": helperTextId, "aria-labelledby": inputLabelId, defaultValue: defaultValue, name: name, id: sliderId, value: value, onChange: handleSliderChange, disabled: disabled, min, max, ...SliderProps }), InputElement] })] }));
});
function getNumberErrorText(val, min, max) {
    const hasMax = typeof max === "number" && !isNaN(max);
    const hasMin = typeof min === "number" && !isNaN(min);
    const isBelow = hasMin && val < min;
    const isAbove = hasMax && val > max;
    if (isNaN(val) || (!isAbove && !isBelow)) {
        return undefined;
    }
    else if (hasMin && hasMax) {
        return `Value must be between ${min} and ${max}.`;
    }
    else if (hasMin) {
        return `Value must be greater than ${min}.`;
    }
    else if (hasMax) {
        return `Value must be less than ${max}.`;
    }
    else {
        return undefined;
    }
}
export default FormLabelSliderField;
