import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useMemo } from "react";
import FormControl from "../FormControl/index.js";
import FormHelperText from "../FormHelperText/index.js";
import FormLabel from "../FormLabel/index.js";
import Input from "../Input/index.js";
import Select from "../Select/index.js";
import { useId } from "../utils/react.js";
/**
 * Like TextField, but uses a FormLabel instead of an InputLabel. Also allows
 * for inline help.
 */
const FormLabelTextField = forwardRef((props, ref) => {
    const { autoComplete, autoFocus = false, children, defaultValue, FormHelperTextProps, fullWidth = false, helperText, id: idProp, InputLabelProps, inputProps, InputProps, inputRef, label, maxRows, minRows, multiline = false, name, nativeSelect = false, onBlur, onChange, onFocus, placeholder, rows, select = false, SelectProps, slotProps, type, value, ...other } = props;
    const id = useId(idProp);
    const helperTextId = helperText && id ? `${id}-helper-text` : undefined;
    const inputLabelId = label && id ? `${id}-label` : undefined;
    const { formHelperTextProps, inputLabelProps, htmlInputProps, propsForInput, selectProps } = useMemo(() => {
        const formHelperTextProps = (slotProps?.formHelperText ??
            FormHelperTextProps ??
            {});
        const htmlInputProps = slotProps?.htmlInput ?? inputProps;
        const inputLabelProps = (slotProps?.inputLabel ??
            InputLabelProps ??
            {});
        const propsForInput = (slotProps?.input ??
            InputProps ??
            {});
        const selectProps = (slotProps?.select ??
            SelectProps ??
            {});
        return {
            formHelperTextProps,
            htmlInputProps,
            inputLabelProps,
            propsForInput,
            selectProps,
        };
    }, [
        FormHelperTextProps,
        InputLabelProps,
        inputProps,
        InputProps,
        SelectProps,
        slotProps,
    ]);
    if (select || nativeSelect) {
        // Unset defaults from textbox inputs.
        if (!selectProps || (!selectProps.native && !nativeSelect)) {
            propsForInput.id = undefined;
        }
        propsForInput["aria-describedby"] = undefined;
    }
    const InputElement = (_jsx(Input
    // All of the properties fron here down to `InputProps` can be overridden by it.
    // Any after that must be controlled by this component itself.
    , { 
        // All of the properties fron here down to `InputProps` can be overridden by it.
        // Any after that must be controlled by this component itself.
        autoComplete: autoComplete, 
        // Disabling this linting rule since the intent is to forward it
        // if it exists rather than set it.
        //
        // eslint-disable-next-line jsx-a11y/no-autofocus
        autoFocus: autoFocus, defaultValue: defaultValue, fullWidth: fullWidth, inputProps: htmlInputProps, inputRef: inputRef, maxRows: maxRows, minRows: minRows, multiline: multiline, name: name, onBlur: onBlur, onChange: onChange, onFocus: onFocus, placeholder: placeholder, rows: rows, type: type, value: value, ...propsForInput, "aria-describedby": helperTextId, id: id }));
    return (_jsxs(FormControl, { fullWidth: fullWidth, ref: ref, ...other, children: [label && (_jsx(FormLabel, { ...inputLabelProps, htmlFor: id, id: inputLabelId, children: label })), helperText && (_jsx(FormHelperText, { ...formHelperTextProps, id: helperTextId, children: helperText })), select || nativeSelect ? (_jsx(Select, { "aria-describedby": helperTextId, id: id, labelId: inputLabelId, value: value, input: InputElement, ...selectProps, ...(nativeSelect && { native: true }), children: children })) : (InputElement)] }));
});
export default FormLabelTextField;
