import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import clsx from "clsx";
import FormControl, { formControlClasses } from "../FormControl/index.js";
import FormControlLabel from "../FormControlLabel/index.js";
import { styled, mergeStyles } from "../styles/index.js";
const PREFIX = "GcxInlineFormControl";
const gcxInlineFormControlClasses = {
    formControlLabelRoot: `${PREFIX}-formControlLabelRoot`,
    formControl: `${PREFIX}-formControl`,
    formControlLabelLabel: `${PREFIX}-formControlLabelLabel`,
};
export const inlineFormControlClasses = {
    ...formControlClasses,
    ...gcxInlineFormControlClasses,
};
const StyledFormControl = styled(FormControl)({
    [`& .${inlineFormControlClasses.inlineHelp}`]: {
        display: "flex",
        position: "inherit",
    },
    [`& .${inlineFormControlClasses.formControlLabelRoot}`]: {
        display: "flex",
        flex: 1,
    },
    [`&.${inlineFormControlClasses.formControl}`]: {
        display: "flex",
        /**
         * Override Mui's flexDirection
         */
        flexDirection: "row",
        alignItems: "center",
    },
    [`& .${inlineFormControlClasses.formControlLabelLabel}`]: {
        fontWeight: 500,
    },
});
/**
 * Used for displaying a checkbox, switch, or Link with inline help.
 */
const InlineFormControl = ({ children, className, classes, control, label, ...props }) => {
    const { formControlLabelRoot: formControlLabelRootClass, formControlLabelLabel: formControlLabelLabelClass, formControl: formControlClass, ...otherClasses } = mergeStyles(inlineFormControlClasses, classes);
    return (_jsxs(StyledFormControl, { className: clsx("GcxInlineFormControl", formControlClass, className), ...props, classes: otherClasses, children: [_jsx(FormControlLabel, { classes: { root: formControlLabelRootClass, label: formControlLabelLabelClass }, control: control, label: label }), children] }));
};
export default InlineFormControl;
