import type { ReactNode } from "react";
export declare const inlineHelpClasses: {
    root: string;
    paper: string;
    button: string;
    errorIcon: string;
};
export type InlineHelpClassKey = keyof typeof inlineHelpClasses;
export type InlineHelpClasses = Record<InlineHelpClassKey, string>;
export interface InlineHelpProps {
    /**
     * Optionally the children to be rendered by the InlineHelp.
     */
    children?: ReactNode;
    /**
     * The CSS class name of the root element.
     */
    className?: string;
    /**
     * Additional CSS classes to be applied to the component.
     */
    classes?: Partial<InlineHelpClasses>;
    /**
     * The help icon node to show.
     */
    icon?: ReactNode;
    /**
     * Callback fired when the help content is closed.
     */
    onClose?: () => void;
    /**
     * The title of the IconButton
     */
    title?: string;
    /**
     * The link displayed in the inline help.
     */
    url?: {
        /**
         * The label to be displayed for the link .
         */
        label: string;
        /**
         * The href of the link.
         */
        href: string;
        /**
         * A callback function for when the link is clicked.
         */
        onClick?: (link: string) => void;
    };
}
declare const InlineHelp: import("react").ForwardRefExoticComponent<InlineHelpProps & import("react").RefAttributes<HTMLDivElement>>;
export default InlineHelp;
