import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useFormControl } from "@mui/material/FormControl";
import clsx from "clsx";
import { forwardRef, useState } from "react";
import Box from "../Box/index.js";
import IconButton from "../IconButton/index.js";
import Link from "../Link/index.js";
import Popover from "../Popover/index.js";
import Typography from "../Typography/index.js";
import HelpIcon from "../icons/Help.js";
import { styled, mergeStyles, useTheme } from "../styles/index.js";
const PREFIX = "GcxInlineHelp";
export const inlineHelpClasses = {
    root: `${PREFIX}-root`,
    paper: `${PREFIX}-paper`,
    button: `${PREFIX}-button`,
    errorIcon: `${PREFIX}-errorIcon`,
};
const LTR_ORIGIN = {
    vertical: "top",
    horizontal: "left",
};
const RTL_ORIGIN = {
    vertical: "top",
    horizontal: "right",
};
// Popover styling needs to be applied separately here, since the popover will
// not be a child of the Root in the DOM due to use of a React portal.
const StyledPopover = styled(Popover)(({ theme: { spacing, typography: { pxToRem }, }, }) => ({
    [`& .${inlineHelpClasses.paper}`]: {
        maxWidth: pxToRem(350),
        padding: spacing(2),
        overflowWrap: "anywhere",
    },
}));
const InlineHelp = forwardRef(({ children, classes: classesProp, className, icon, onClose, title, url, ...other }, ref) => {
    const [iconBtnEl, setIconBtnEl] = useState();
    const theme = useTheme();
    const classes = mergeStyles(inlineHelpClasses, classesProp);
    const formControl = useFormControl();
    const handleIconPopoverOpen = (event) => setIconBtnEl(event.currentTarget);
    const handleIconPopoverClose = () => setIconBtnEl(undefined);
    return (_jsxs(Box, { className: clsx(classes.root, className), ref: ref, ...other, children: [_jsx(IconButton, { onClick: handleIconPopoverOpen, title: title, size: "small", "data-test": `${PREFIX}-button`, className: clsx(classes.button, {
                    [classes.errorIcon]: formControl?.error,
                }), children: icon ?? _jsx(HelpIcon, { fontSize: "small" }) }), _jsxs(StyledPopover, { anchorEl: iconBtnEl, open: !!iconBtnEl, classes: { paper: classes.paper }, anchorOrigin: theme.direction === "rtl" ? RTL_ORIGIN : LTR_ORIGIN, transformOrigin: theme.direction === "rtl" ? RTL_ORIGIN : LTR_ORIGIN, onClose: () => {
                    handleIconPopoverClose();
                    onClose?.();
                }, children: [_jsx(Typography, { children: children }), url && (_jsx(Link, { align: "right", display: "block", href: url.href, onClick: () => url.onClick?.(url.href), target: "_blank", variant: "body2", children: url.label }))] })] }));
});
export default InlineHelp;
