import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import clsx from "clsx";
import { forwardRef } from "react";
import Fade from "../Fade/index.js";
import { alpha, keyframes, styled, mergeStyles } from "../styles/index.js";
const PREFIX = "GcxLoader";
export const loaderClasses = {
    root: `${PREFIX}-root`,
    dot: `${PREFIX}-dot`,
    showBackground: `${PREFIX}-showBackground`,
    visible: `${PREFIX}-visible`,
};
const loaderAnimation = keyframes({
    "50%": {
        transform: "scale(1)",
        opacity: 1,
    },
    "100%": {
        opacity: 0,
    },
});
const Root = styled("div")(({ theme: { palette } }) => ({
    position: "absolute",
    top: 0,
    left: 0,
    width: "100%",
    height: "100%",
    visibility: "hidden",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    zIndex: 1,
    "&, &:focus": {
        // Prevent blue outline of overlay when element is focused
        outline: "none !important",
    },
    [`& .${loaderClasses.dot}`]: {
        width: 32,
        height: 32,
        border: `6px solid ${palette.grey[600]}`,
        backgroundColor: palette.grey[600],
        borderRadius: "50%",
        float: "left",
        margin: "0 16px",
        transform: "scale(0)",
        animation: `${loaderAnimation} 1500ms ease infinite 0ms`,
        "&:nth-of-type(2)": {
            animation: `${loaderAnimation} 1500ms ease infinite 100ms`,
        },
        "&:nth-of-type(3)": {
            animation: `${loaderAnimation} 1500ms ease infinite 200ms`,
        },
    },
    [`&.${loaderClasses.showBackground}`]: {
        backgroundColor: palette.mode === "dark"
            ? alpha(palette.common.white, 0.15)
            : alpha(palette.common.black, 0.4),
        [`& .${loaderClasses.dot}`]: {
            borderColor: palette.common.white,
            backgroundColor: palette.common.white,
        },
    },
    [`&.${loaderClasses.visible}`]: {
        visibility: "visible",
    },
}));
const Loader = forwardRef(({ className, classes: classesProp, showBackground, visible, children }, ref) => {
    const classes = mergeStyles(loaderClasses, classesProp);
    return (_jsx(Fade, { in: visible, ref: ref, children: _jsxs(Root, { "aria-hidden": "true", className: clsx(classes.root, className, {
                [classes.showBackground]: showBackground,
                [classes.visible]: visible,
            }), "data-test": "Loader-root", tabIndex: -1, children: [_jsxs("div", { children: [_jsx("div", { className: classes.dot }), _jsx("div", { className: classes.dot }), _jsx("div", { className: classes.dot })] }), children && _jsx("div", { "data-test": "Loader-children", children: children })] }) }));
});
export default Loader;
