import type { FC } from "react";
import type { BoxProps } from "../Box/index.js";
/**
 * Properties for the `Markdown` component.
 */
export interface MarkdownProps extends BoxProps {
    /**
     * The markdown text to render.
     */
    markdown: string;
    /**
     * Override the default sanitization behaviour with a caller-supplied
     * sanitization function that ensures that the resulting HTML is safe to
     * insert into the DOM.
     */
    sanitize?: (unsafeHtml: string) => string;
    /**
     * If specified, produces HTML that is valid for contexts where only inline
     * content is allowed (e.g. inside `<h1>` or `<span>` tags). HTML tags for
     * block-level elements will be removed, but any text content will be
     * preserved.
     */
    inline?: boolean;
    /**
     * If true, any HTML in the markdown will be escaped rather than passed
     * through directly to the output as normal (since Markdown is a superset of
     * HTML). This is useful in situations where you wish to only support pure
     * Markdown syntax without also supporting HTML syntax. The default is
     * `false`.
     *
     * IMPORTANT: The resulting HTML still needs to be sanitized whether or not
     * this option is set.
     */
    escapeHtml?: boolean;
    /**
     * An optional value to apply to external hyperlinks via the `target`
     * attribute.
     *
     * If this is omitted, links may still open in a separate target if the host
     * page specifies a `target` via the `<base>` element in its `<head>`.
     */
    linkTarget?: string;
}
/**
 * A component that renders markdown as HTML.
 */
declare const Markdown: FC<MarkdownProps>;
export default Markdown;
