import { jsx as _jsx } from "react/jsx-runtime";
import { useRef } from "react";
import Box, {} from "../Box/index.js";
import { styled } from "../styles/index.js";
const SecondaryActionContainer = styled(Box)({
    display: "flex",
    flexShrink: 0,
});
/**
 * For use within a MenuList (or other list that implements arrow key
 * navigation). The standard ListItemSecondaryAction will break keyboard
 * navigation in this type of list.
 *
 * @param props The component properties.
 */
const MenuItemSecondaryAction = props => {
    const ref = useRef(null);
    const { className, ...otherProps } = props;
    const onKeyDown = (event) => {
        const { key } = event;
        if (key === "ArrowUp" || key === "ArrowDown" || key === "Home" || key === "End") {
            // Switch focus to the parent list item, then let the key event
            // propagate to get the normal behavior of pressing these keys.
            ref.current?.parentElement?.focus();
        }
        else if (key !== "Escape") {
            // Prevent propagation to the primary action.
            event.stopPropagation();
        }
    };
    return (_jsx(SecondaryActionContainer, { className: className, onClick: event => {
            event.stopPropagation();
        }, onKeyDown: onKeyDown, onMouseDown: event => {
            // This will stop child ripples from propagating.
            event.stopPropagation();
        }, ref: ref, ...otherProps }));
};
export default MenuItemSecondaryAction;
