import { jsx as _jsx } from "react/jsx-runtime";
import { Alert, CircularProgress, useTheme } from "@mui/material";
import { useState } from "react";
import IconButton from "../IconButton/index.js";
import Snackbar from "../Snackbar/index.js";
import CloseIcon from "../icons/Close.js";
/**
 * A Helper component that wraps a Mui Snackbar and displays a circular progress
 * representing the current auto hide duration.
 */
const Notification = ({ alertProps, closeButtonTitle, children, ...props }) => {
    const [progress, setProgress] = useState(100);
    const { spacing } = useTheme();
    return (_jsx(Snackbar, { ...props, timeoutProgress: remaining => {
            if (props.autoHideDuration) {
                setProgress((remaining / props.autoHideDuration) * 100);
            }
        }, children: _jsx(Alert, { ...alertProps, action: [
                props.autoHideDuration && (_jsx(CircularProgress, { variant: "determinate", value: progress, color: "inherit", sx: {
                        position: "absolute",
                    }, 
                    // Magic size to match the close icon button perfectly.
                    size: spacing(4.8) }, "progress")),
                _jsx(IconButton, { title: closeButtonTitle, color: "inherit", onClick: () => props.onClose?.({}, "escapeKeyDown"), children: _jsx(CloseIcon, { fontSize: "small" }) }, "close"),
            ], children: children }) }));
};
export default Notification;
