import { type InputProps } from "@mui/material/Input";
export declare const DEFAULT_DECIMAL_PLACES = 16;
export type ErrorType = "NaN" | "out-of-range" | "max-decimals" | "unknown";
/**
 * Properties for the `NumberInput` component.
 */
export interface NumberInputProps extends Omit<InputProps, "type" | "onChange" | "value" | "onError"> {
    /**
     * Sets the value to show in the input for controlled components. If not
     * specified, the input will be uncontrolled instead.
     */
    value?: number;
    /**
     * A callback to fire when selected values change.
     */
    onChange?: (value: number | undefined) => void;
    /**
     * The maximum value possible for the number input.
     */
    max?: number;
    /**
     * The minimum value possible for the number input.
     */
    min?: number;
    /**
     * Executed when the input moves into an error state.
     */
    onError?: (value: number, textValue: string, type: ErrorType) => void;
    /**
     * Executed when the input moves out of an error state.
     */
    onErrorEnd?: (value: number, textValue: string) => void;
    /**
     * Whether to consider an empty field ("") as valid. When this property is
     * true and the field is set to an empty value, the onChange callback will
     * be executed with an undefined argument value.
     */
    allowUndefined?: boolean;
    /**
     * The maximum number of decimal places. Must be a number between 0 and 16.
     * Defaults to 16.
     */
    maxDecimalPlaces?: number;
    /**
     * Whether or not the input should automatically correct invalid values on
     * blur to the last valid value. Defaults to true.
     */
    correctOnBlur?: boolean;
}
/**
 * A number input component that leverages the NumberFormatContext for
 * formatting and parsing. Default formatting and parsing can be overridden by
 * wrapping this component in a NumberFormatContext.Provider.
 */
declare const NumberInput: import("react").ForwardRefExoticComponent<Omit<NumberInputProps, "ref"> & import("react").RefAttributes<unknown>>;
export default NumberInput;
