import { jsx as _jsx } from "react/jsx-runtime";
import SnackbarMUI, {} from "@mui/material/Snackbar";
import { useEffect, useRef } from "react";
// MUST be the first export, since some of the exports are overridden below.
export * from "@mui/material/Snackbar";
const UPDATE_TIME = 100;
const Snackbar = ({ open, onBlur, onClose, onClick, onFocus, onMouseEnter, onTouchStart, onMouseLeave, autoHideDuration: autoHideDurationInitial, timeoutProgress, ...others }) => {
    const timeoutHandle = useRef();
    const autoHideDuration = useRef(autoHideDurationInitial);
    const useTimeout = !!autoHideDurationInitial;
    const cancelTimeout = () => {
        if (useTimeout) {
            timeoutHandle.current?.remove();
            timeoutHandle.current = undefined;
            autoHideDuration.current = 0;
            timeoutProgress?.(0);
        }
    };
    const pauseTimeout = () => {
        timeoutHandle.current?.remove();
        timeoutHandle.current = undefined;
    };
    const resumeTimeout = () => {
        if (open && useTimeout && autoHideDuration.current) {
            const timeout = window.setInterval(() => {
                if (autoHideDuration.current) {
                    autoHideDuration.current = Math.max(autoHideDuration.current - UPDATE_TIME, 0);
                    timeoutProgress?.(autoHideDuration.current);
                }
                else {
                    cancelTimeout();
                    onClose?.({}, "timeout");
                }
            }, UPDATE_TIME);
            timeoutHandle.current = {
                remove: () => {
                    window.clearInterval(timeout);
                },
            };
        }
    };
    useEffect(() => {
        if (open && useTimeout) {
            // reset initial timeout.
            autoHideDuration.current = autoHideDurationInitial;
            timeoutProgress?.(autoHideDurationInitial);
            resumeTimeout();
        }
        return cancelTimeout;
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [open, autoHideDurationInitial]);
    return (_jsx(SnackbarMUI, { open: open, onClose: onClose, onTouchStart: event => {
            cancelTimeout();
            onTouchStart?.(event);
        }, onMouseEnter: event => {
            pauseTimeout();
            onMouseEnter?.(event);
        }, onMouseLeave: event => {
            resumeTimeout();
            onMouseLeave?.(event);
        }, onFocus: event => {
            pauseTimeout();
            onFocus?.(event);
        }, onBlur: event => {
            resumeTimeout();
            onBlur?.(event);
        }, onClick: event => {
            cancelTimeout();
            onClick?.(event);
        }, ...others }));
};
export default Snackbar;
