import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useRef } from "react";
import { fonts } from "./fonts.js";
import { DEFAULT_LANGUAGE } from "./utilities.js";
import Box from "../Box/index.js";
import FormLabelAutocompleteField from "../FormLabelAutocompleteField/FormLabelAutocompleteField.js";
import FormLabelSliderField from "../FormLabelSliderField/index.js";
import FormLabelTextField from "../FormLabelTextField/index.js";
import { useId } from "../utils/react.js";
const getDecorationValues = (t) => [
    { id: "none", label: t.decorationNone },
    { id: "line-through", label: t.decorationLineThrough },
    { id: "underline", label: t.decorationLineUnderline },
];
const capitalizeFirstLetter = (value) => `${value.charAt(0).toUpperCase() + value.slice(1)}`;
const defaultFontJson = {
    size: 9,
    style: "normal",
    decoration: "none",
    weight: "normal",
    family: "sans-serif",
};
export const FontInput = ({ font, fontFamilies, languageResources, onChange, AutoCompleteComponent, TextInputComponent, NumberInputComponent, ...props }) => {
    const AutocompleteInput = AutoCompleteComponent ?? (FormLabelAutocompleteField);
    const FormTextInput = TextInputComponent ?? FormLabelTextField;
    const FormNumberInput = NumberInputComponent ?? FormLabelSliderField;
    const { current: fontList } = useRef([...(fontFamilies ?? fonts)]);
    const text = { ...DEFAULT_LANGUAGE, ...languageResources };
    const labelId = useId();
    const clampValue = (key, minValue = 0, maxValue = 100) => {
        const clampedValue = Math.min(maxValue, Math.max(minValue, font?.[key] ?? minValue));
        if (font?.[key] !== clampedValue) {
            onChange({ ...font, [key]: clampedValue });
        }
    };
    const updateValue = (key, value) => {
        onChange({ ...font, [key]: value });
    };
    if (!font) {
        onChange(defaultFontJson);
        return null;
    }
    // https://developers.arcgis.com/javascript/latest/api-reference/esri-symbols-Font.html
    const fontWithDefaults = {
        family: font.family ?? "sans-serif",
        style: font.style ?? "normal",
        weight: font.weight ?? "normal",
        decoration: font.decoration ?? "none",
        size: font.size ?? 9,
    };
    let fontFamily = fontList.find(f => f.font.family === fontWithDefaults.family &&
        f.font.style === fontWithDefaults.style &&
        f.font.weight === fontWithDefaults.weight);
    if (!fontFamily) {
        let name = fontWithDefaults.family.split("-").map(capitalizeFirstLetter).join(" ");
        if (font.style !== "normal") {
            name += ` ${capitalizeFirstLetter(fontWithDefaults.style)}`;
        }
        if (font.weight !== "normal") {
            name += ` ${capitalizeFirstLetter(fontWithDefaults.weight)}`;
        }
        fontFamily = {
            name,
            font: {
                family: fontWithDefaults.family,
                style: fontWithDefaults.style,
                weight: fontWithDefaults.weight,
            },
        };
        fontList.push(fontFamily);
    }
    return (_jsxs(Box, { ...props, children: [_jsx(AutocompleteInput, { fullWidth: true, disableClearable: true, options: fontList, label: text.fontFamily, "aria-labelledby": labelId, filterOptions: (options, state) => fontList.filter(f => f.name.toLocaleLowerCase().includes(state.inputValue.toLocaleLowerCase())), getOptionLabel: option => option.name, value: fontFamily, onChange: (event, newValue, reason, details) => {
                    onChange({
                        ...font,
                        family: newValue?.font?.family,
                        style: newValue?.font?.style,
                        weight: newValue?.font?.weight,
                    });
                } }), _jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                    step: 0.5,
                    min: 0,
                    max: 100,
                }, InputProps: {
                    onBlur: (event) => {
                        clampValue("size", 0, 100);
                    },
                    min: 0,
                    max: 100,
                }, label: text.fontSize, value: font.size, onChange: value => {
                    updateValue("size", value);
                } }), _jsx(FormTextInput, { fullWidth: true, nativeSelect: true, label: text.decoration, value: font.decoration, onChange: event => {
                    const { value } = event.target;
                    updateValue("decoration", value);
                }, children: getDecorationValues(text).map(ls => (_jsx("option", { value: ls.id, children: ls.label }, ls.id))) })] }));
};
