import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useCallback, useState } from "react";
import UnsupportedSymbol, {} from "./UnsupportedSymbol.js";
import { DEFAULT_FORMAT_NUMBER, DEFAULT_LANGUAGE, DEFAULT_PARSE_NUMBER, getFillColor, getFillStyle, getLineColor, getLineStyle, getLineWidth, toColor, toRgbaString, } from "./utilities.js";
import Box, {} from "../Box/index.js";
import FormLabelColorField, {} from "../FormLabelColorField/index.js";
import FormLabelSliderField, {} from "../FormLabelSliderField/index.js";
import FormLabelTextField, {} from "../FormLabelTextField/index.js";
export function symbolIsSupported(symbol) {
    const type = symbol.type;
    return type === "esriSFS";
}
const SimpleFillSymbolInput = props => {
    const { onChange, symbol, languageResources, colorResources, children, parseNumber, formatNumber, isSupported = symbolIsSupported, TextInputComponent, NumberInputComponent, ColorInputComponent, ...other } = {
        parseNumber: DEFAULT_PARSE_NUMBER,
        formatNumber: DEFAULT_FORMAT_NUMBER,
        ...props,
    };
    const isSupportedSymbol = isSupported(symbol);
    const text = {
        ...DEFAULT_LANGUAGE,
        ...languageResources,
    };
    const { type } = symbol;
    const FormTextInput = TextInputComponent ?? FormLabelTextField;
    const FormNumberInput = NumberInputComponent ?? FormLabelSliderField;
    const FormColorInput = ColorInputComponent ?? FormLabelColorField;
    const [lineStyle, setLineStyle] = useState(getLineStyle(symbol));
    const [fillStyle, setFillStyle] = useState(getFillStyle(symbol));
    const [lineColor, setLineColor] = useState(getLineColor(symbol));
    const [fillColor, setFillColor] = useState(getFillColor(symbol));
    const [lineWidth, setLineWidth] = useState(getLineWidth(symbol));
    useEffect(() => {
        setLineColor(getLineColor(symbol));
        setLineStyle(getLineStyle(symbol));
        setLineWidth(getLineWidth(symbol));
        setFillColor(getFillColor(symbol));
        setFillStyle(getFillStyle(symbol));
    }, [symbol]);
    const handleLineWidthBlur = useCallback((event) => {
        setLineWidth(Math.min(100, Math.max(0, lineWidth ?? 0)));
    }, [lineWidth]);
    // The rule is correct, but without the useless constraint, the TSX parser
    // gets confused and tries to interpret it as a React element.
    //
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-type-constraint
    const handleStateChange = (state, propName, setState) => {
        setState(state);
        onChange?.(getCurrentProperties({ [propName]: state }));
    };
    const getCurrentProperties = (newState = {}) => {
        switch (type) {
            case "esriSFS":
                return {
                    type,
                    color: newState.fillColor ?? fillColor,
                    outline: {
                        color: newState.lineColor ?? lineColor,
                        width: newState.lineWidth ?? lineWidth,
                        style: newState.lineStyle ?? lineStyle,
                        type: "esriSLS",
                    },
                    style: newState.fillStyle ?? fillStyle,
                };
            case "esriSLS":
            case "esriSMS":
            case "esriTS":
                return { type };
        }
    };
    return (_jsxs(Box, { ...other, children: [!isSupportedSymbol && (_jsx(UnsupportedSymbol, { languageResources: languageResources, colorResources: colorResources })), children, isSupportedSymbol && (_jsxs(_Fragment, { children: [_jsx(FormColorInput, { fullWidth: true, label: text.lineColorTitle, onChange: (value) => {
                            handleStateChange(toColor(value), "lineColor", setLineColor);
                        }, value: toRgbaString(lineColor) }), _jsx(FormTextInput, { fullWidth: true, nativeSelect: true, label: text.lineStyleTitle, value: lineStyle, onChange: event => {
                            const { value } = event.target;
                            handleStateChange(value, "lineStyle", setLineStyle);
                        }, children: getSimpleLineStyles(text).map(ls => (_jsx("option", { value: ls.id, children: ls.label }, ls.id))) }), _jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                            step: 0.5,
                            min: 0,
                            max: 25,
                        }, InputProps: {
                            onBlur: handleLineWidthBlur,
                            min: 0,
                            max: 25,
                        }, label: text.lineWidthTitle, value: lineWidth, onChange: value => {
                            handleStateChange(value, "lineWidth", setLineWidth);
                        } }), _jsx(FormColorInput, { fullWidth: true, label: text.fillColorTitle, onChange: (value) => {
                            handleStateChange(toColor(value), "fillColor", setFillColor);
                        }, value: toRgbaString(fillColor) }), _jsx(FormTextInput, { fullWidth: true, nativeSelect: true, label: text.fillStyleTitle, value: fillStyle, onChange: event => {
                            const { value } = event.target;
                            handleStateChange(value, "fillStyle", setFillStyle);
                        }, children: getSimpleFillStyles(text).map(fillStyle => (_jsx("option", { value: fillStyle.id, children: fillStyle.label }, fillStyle.id))) })] }))] }));
};
export default SimpleFillSymbolInput;
export const getSimpleFillStyles = (t) => [
    {
        id: "esriSFSBackwardDiagonal",
        label: t.fillStyleBackwardDiagonal,
    },
    {
        id: "esriSFSCross",
        label: t.fillStyleCross,
    },
    {
        id: "esriSFSDiagonalCross",
        label: t.fillStyleDiagonalCross,
    },
    {
        id: "esriSFSForwardDiagonal",
        label: t.fillStyleForwardDiagonal,
    },
    {
        id: "esriSFSHorizontal",
        label: t.fillStyleHorizontal,
    },
    {
        id: "esriSFSNull",
        label: t.fillStyleNone,
    },
    {
        id: "esriSFSSolid",
        label: t.fillStyleSolid,
    },
    {
        id: "esriSFSVertical",
        label: t.fillStyleVertical,
    },
];
export const getSimpleLineStyles = (t) => [
    {
        id: "esriSLSDash",
        label: t.lineStyleDash,
    },
    {
        id: "esriSLSDashDot",
        label: t.lineStyleDashDot,
    },
    {
        id: "esriSLSDot",
        label: t.lineStyleDot,
    },
    {
        id: "esriSLSLongDash",
        label: t.lineStyleLongDash,
    },
    {
        id: "esriSLSLongDashDot",
        label: t.lineStyleLongDashDot,
    },
    {
        id: "esriSLSNull",
        label: t.lineStyleNone,
    },
    {
        id: "esriSLSShortDash",
        label: t.lineStyleShortDash,
    },
    {
        id: "esriSLSShortDashDot",
        label: t.lineStyleShortDashDot,
    },
    {
        id: "esriSLSShortDashDotDot",
        label: t.lineStyleShortDashDotDot,
    },
    {
        id: "esriSLSShortDot",
        label: t.lineStyleShortDot,
    },
    {
        id: "esriSLSSolid",
        label: t.lineStyleSolid,
    },
];
