import type { FC } from "react";
import type { FontInputProps } from "./FontInput.js";
import type { SymbolJson, TextSymbolJson } from "./SymbolJson.js";
import { type UnsupportedSymbolProps } from "./UnsupportedSymbol.js";
import type { FontFamily } from "./fonts.js";
import type { BoxProps } from "../Box/index.js";
import type { FormLabelAutocompleteFieldProps } from "../FormLabelAutocompleteField/index.js";
import { type FormLabelColorFieldProps } from "../FormLabelColorField/index.js";
import { type FormLabelSliderFieldProps } from "../FormLabelSliderField/index.js";
import { type FormLabelTextFieldProps } from "../FormLabelTextField/index.js";
export interface LanguageResources {
    angleTitle?: string;
    backgroundColor?: string;
    borderLineColor?: string;
    borderLineSize?: string;
    color?: string;
    haloColor?: string;
    haloSize?: string;
    horizontalAlignment?: string;
    horizontalAlignmentLeft?: string;
    horizontalAlignmentRight?: string;
    horizontalAlignmentCenter?: string;
    verticalAlignment?: string;
    verticalAlignmentBaseline?: string;
    verticalAlignmentTop?: string;
    verticalAlignmentMiddle?: string;
    verticalAlignmentBottom?: string;
    xOffsetTitle?: string;
    yOffsetTitle?: string;
}
export interface TextSymbolDisplayOptions {
    showAngle?: boolean;
    showAlignments?: boolean | {
        showVertical?: boolean;
        showHorizontal?: boolean;
    };
    showColor?: boolean;
    showBorder?: boolean;
    showFont?: boolean;
    showHalo?: boolean;
    showOffset?: boolean;
}
export interface TextSymbolInputProps extends Omit<BoxProps, "onChange"> {
    onChange: (symbol: SymbolJson) => void;
    displayOptions?: TextSymbolDisplayOptions;
    symbol: SymbolJson;
    colorResources?: UnsupportedSymbolProps["colorResources"];
    languageResources?: LanguageResources & FontInputProps["languageResources"] & UnsupportedSymbolProps["languageResources"];
    isSupported?: (symbol: SymbolJson) => symbol is TextSymbolJson;
    AutoCompleteComponent?: FC<FormLabelAutocompleteFieldProps<FontFamily, false, true, false>>;
    TextInputComponent?: FC<FormLabelTextFieldProps>;
    NumberInputComponent?: FC<FormLabelSliderFieldProps>;
    ColorInputComponent?: FC<FormLabelColorFieldProps>;
    fontFamilies?: FontFamily[];
}
export declare function symbolIsSupported(symbol: SymbolJson): symbol is TextSymbolJson;
declare const TextSymbolInput: FC<TextSymbolInputProps>;
export default TextSymbolInput;
