import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { FontInput } from "./FontInput.js";
import UnsupportedSymbol, {} from "./UnsupportedSymbol.js";
import { toRgbaString, toColor, DEFAULT_LANGUAGE } from "./utilities.js";
import Box from "../Box/index.js";
import FormLabelColorField, {} from "../FormLabelColorField/index.js";
import FormLabelSliderField, {} from "../FormLabelSliderField/index.js";
import FormLabelTextField, {} from "../FormLabelTextField/index.js";
export function symbolIsSupported(symbol) {
    const type = symbol.type;
    return type === "esriTS";
}
const TextSymbolInput = props => {
    const { onChange, displayOptions: initialDisplayOptions, children, symbol, isSupported = symbolIsSupported, colorResources, languageResources, TextInputComponent, NumberInputComponent, ColorInputComponent, AutoCompleteComponent, fontFamilies, ...others } = props;
    const isSupportedSymbol = isSupported(symbol);
    const text = {
        ...DEFAULT_LANGUAGE,
        ...languageResources,
    };
    const FormTextInput = TextInputComponent ?? FormLabelTextField;
    const FormNumberInput = NumberInputComponent ?? FormLabelSliderField;
    const FormColorInput = ColorInputComponent ?? FormLabelColorField;
    const displayOptions = {
        showColor: true,
        showFont: true,
        showHalo: true,
        ...initialDisplayOptions,
    };
    const clampValue = (key, minValue = 0, maxValue = 100) => {
        const clampedValue = Math.min(maxValue, Math.max(minValue, symbol[key] ?? minValue));
        if (symbol[key] !== clampedValue) {
            onChange({ ...symbol, [key]: clampedValue });
        }
    };
    const updateValue = (key, value) => {
        onChange({ ...symbol, [key]: value });
    };
    return (_jsxs(Box, { ...others, children: [!isSupportedSymbol && (_jsx(UnsupportedSymbol, { languageResources: languageResources, colorResources: colorResources })), children, isSupportedSymbol && (_jsxs(_Fragment, { children: [displayOptions.showFont && (_jsx(FontInput, { font: symbol.font, onChange: value => updateValue("font", value), languageResources: text, fontFamilies: fontFamilies, AutoCompleteComponent: AutoCompleteComponent })), displayOptions.showAlignments && (_jsxs(_Fragment, { children: [(displayOptions.showAlignments === true ||
                                displayOptions.showAlignments.showHorizontal) && (_jsx(FormTextInput, { fullWidth: true, nativeSelect: true, label: text.horizontalAlignment, value: symbol.horizontalAlignment, onChange: event => {
                                    const { value } = event.target;
                                    updateValue("horizontalAlignment", value);
                                }, children: getHorizontalAlignmentValues(text).map(ls => (_jsx("option", { value: ls.id, children: ls.label }, ls.id))) })), (displayOptions.showAlignments === true ||
                                displayOptions.showAlignments.showVertical) && (_jsx(FormTextInput, { fullWidth: true, nativeSelect: true, label: text.verticalAlignment, value: symbol.verticalAlignment, onChange: event => {
                                    const { value } = event.target;
                                    updateValue("verticalAlignment", value);
                                }, children: getVerticalAlignmentValues(text).map(ls => (_jsx("option", { value: ls.id, children: ls.label }, ls.id))) }))] })), displayOptions.showColor && (_jsx(FormColorInput, { fullWidth: true, label: text.color, onChange: (value) => {
                            updateValue("color", toColor(value));
                        }, value: toRgbaString(symbol.color) })), displayOptions.showHalo && (_jsxs(_Fragment, { children: [_jsx(FormColorInput, { fullWidth: true, label: text.haloColor, onChange: (value) => {
                                    updateValue("haloColor", toColor(value));
                                }, value: toRgbaString(symbol.haloColor) }), _jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                                    step: 0.5,
                                    min: 0,
                                    max: 10,
                                }, InputProps: {
                                    onBlur: (event) => {
                                        clampValue("haloSize", 0, 10);
                                    },
                                    min: 0,
                                    max: 100,
                                }, label: text.haloSize, value: symbol.haloSize, onChange: value => {
                                    updateValue("haloSize", value);
                                } })] })), displayOptions.showColor && (_jsx(FormColorInput, { fullWidth: true, label: text.backgroundColor, onChange: (value) => {
                            updateValue("backgroundColor", toColor(value));
                        }, value: toRgbaString(symbol.backgroundColor) })), displayOptions.showBorder && (_jsxs(_Fragment, { children: [_jsx(FormColorInput, { fullWidth: true, label: text.borderLineColor, onChange: (value) => {
                                    updateValue("borderLineColor", toColor(value));
                                }, value: toRgbaString(symbol.borderLineColor) }), _jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                                    step: 0.5,
                                    min: 0,
                                    max: 100,
                                }, InputProps: {
                                    onBlur: (event) => {
                                        clampValue("borderLineSize", 0, 100);
                                    },
                                    min: 0,
                                    max: 100,
                                }, label: text.borderLineSize, value: symbol.borderLineSize, onChange: value => {
                                    updateValue("borderLineSize", value);
                                } })] })), displayOptions.showAngle && (_jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                            step: 0.5,
                            min: 0,
                            max: 360,
                        }, InputProps: {
                            onBlur: (event) => {
                                clampValue("angle", 0, 360);
                            },
                            min: 0,
                            max: 360,
                        }, label: text.angleTitle, value: symbol.angle, onChange: value => {
                            updateValue("angle", value);
                        } })), displayOptions.showOffset && (_jsxs(_Fragment, { children: [_jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                                    step: 0.5,
                                    min: 0,
                                    max: 100,
                                }, InputProps: {
                                    onBlur: (event) => {
                                        clampValue("xoffset", 0, 100);
                                    },
                                    min: 0,
                                    max: 100,
                                }, label: text.xOffsetTitle, value: symbol.xoffset, onChange: value => {
                                    updateValue("xoffset", value);
                                } }), _jsx(FormNumberInput, { fullWidth: true, SliderProps: {
                                    step: 0.5,
                                    min: 0,
                                    max: 100,
                                }, InputProps: {
                                    onBlur: (event) => {
                                        clampValue("yoffset", 0, 100);
                                    },
                                    min: 0,
                                    max: 100,
                                }, label: text.yOffsetTitle, value: symbol.yoffset, onChange: value => {
                                    updateValue("yoffset", value);
                                } })] }))] }))] }));
};
export default TextSymbolInput;
const getHorizontalAlignmentValues = (t) => [
    { id: "left", label: t.horizontalAlignmentLeft },
    { id: "right", label: t.horizontalAlignmentRight },
    { id: "center", label: t.horizontalAlignmentCenter },
];
const getVerticalAlignmentValues = (t) => [
    { id: "baseline", label: t.verticalAlignmentBaseline },
    { id: "top", label: t.verticalAlignmentTop },
    { id: "middle", label: t.verticalAlignmentMiddle },
    { id: "bottom", label: t.verticalAlignmentBottom },
];
