export const DEFAULT_LANGUAGE = {
    fillColorTitle: "Fill Color",
    fillStyleTitle: "Fill Style",
    lineColorTitle: "Line Color",
    lineStyleTitle: "Line Style",
    lineWidthTitle: "Line Width",
    markerAngleTitle: "Marker Angle",
    xOffsetTitle: "X Offset",
    yOffsetTitle: "Y Offset",
    markerSizeTitle: "Marker Size",
    markerStyleTitle: "Marker Style",
    symbolUnsupportedErrorMessage: "You are attempting to edit a symbol that is not currently supported.",
    markerStyleCircle: "Circle",
    markerStyleCross: "Cross",
    markerStyleDiamond: "Diamond",
    markerStyleSquare: "Square",
    markerStyleTriangle: "Triangle",
    markerStyleX: "X",
    lineStyleDash: "Dash",
    lineStyleDashDot: "Dash Dot",
    lineStyleDot: "Dot",
    lineStyleLongDashDot: "Long Dash Dot",
    lineStyleLongDash: "Long Dash",
    lineStyleNone: "None",
    lineStyleShortDashDotDot: "Short Dash Dot Dot",
    lineStyleShortDashDot: "Short Dash Dot",
    lineStyleShortDash: "Short Dash",
    lineStyleShortDot: "Short Dot",
    lineStyleSolid: "Solid",
    fillStyleBackwardDiagonal: "Backward Diagonal",
    fillStyleCross: "Cross",
    fillStyleDiagonalCross: "Diagonal Cross",
    fillStyleForwardDiagonal: "Forward Diagonal",
    fillStyleHorizontal: "Horizontal",
    fillStyleNone: "None",
    fillStyleSolid: "Solid",
    fillStyleVertical: "Vertical",
    angleTitle: "Text Angle",
    backgroundColor: "Background Color",
    borderLineColor: "Border line Color",
    borderLineSize: "Border line Size",
    color: "Color",
    font: "Font",
    fontSize: "Font Size",
    fontFamily: "Font Family",
    fontStyle: "Font Style",
    fontWeight: "Font Style",
    haloColor: "Halo Color",
    haloSize: "Halo Size",
    horizontalAlignment: "Horizontal Alignments",
    horizontalAlignmentLeft: "Left",
    horizontalAlignmentRight: "Right",
    horizontalAlignmentCenter: "Center",
    verticalAlignment: "Vertical Alignments",
    verticalAlignmentBaseline: "Baseline",
    verticalAlignmentTop: "Top",
    verticalAlignmentMiddle: "Middle",
    verticalAlignmentBottom: "Bottom",
    decoration: "Font Decoration",
    decorationNone: "None",
    decorationLineThrough: "Line-through",
    decorationLineUnderline: "Underline",
};
export const NO_FILL_MARKER_STYLES = [
    "esriSMSCross",
    "esriSMSX",
];
export const DEFAULT_PARSE_NUMBER = (s) => typeof s === "string" ? +s : 0;
export const DEFAULT_FORMAT_NUMBER = (n) => typeof n === "number" ? `${n}` : "0";
export const getLineStyle = (symbol) => {
    switch (symbol?.type) {
        case "esriSMS":
        case "esriSFS":
            return symbol.outline?.style;
        case "esriSLS":
            return symbol.style;
        case "esriTS":
            return undefined;
    }
};
export const getFillStyle = (symbol) => {
    switch (symbol?.type) {
        case "esriSFS":
            return symbol.style;
        case "esriSLS":
        case "esriSMS":
        case "esriTS":
            return undefined;
    }
};
export const getLineColor = (symbol) => {
    switch (symbol?.type) {
        case "esriSMS":
        case "esriSFS":
            return symbol.outline?.color;
        case "esriSLS":
            return symbol.color;
        case "esriTS":
            return undefined;
    }
};
export const getFillColor = (symbol) => {
    switch (symbol?.type) {
        case "esriSMS":
        case "esriSFS":
            return symbol.color;
        case "esriSLS":
        case "esriTS":
            return undefined;
    }
};
export const getLineWidth = (symbol) => {
    switch (symbol?.type) {
        case "esriSMS":
        case "esriSFS":
            return symbol.outline?.width;
        case "esriSLS":
            return symbol.width;
        case "esriTS":
            return undefined;
    }
};
export const getMarkerProperty = (symbol, property) => {
    if (symbol?.type !== "esriSMS") {
        return undefined;
    }
    return symbol[property];
};
export const toRgbaString = (color) => {
    if (!color) {
        return DEFAULT_RGBA_STRING;
    }
    const [r, g, b, a] = color;
    const aVal = a / 255;
    return `rgba(${r}, ${g}, ${b}, ${isNaN(aVal) ? 1 : aVal})`;
};
export const toColor = (color) => {
    if (!color) {
        return DEFAULT_COLOR;
    }
    return fromRgbaString(color) ?? fromRgbString(color) ?? DEFAULT_COLOR;
};
export const fromRgbString = (color) => {
    const result = /rgb\(([\d.]+), ([\d.]+), ([\d.]+)\)/.exec(color);
    if (result) {
        const [, r, g, b] = result;
        return [+r, +g, +b, 255];
    }
    return undefined;
};
export const fromRgbaString = (color) => {
    const result = /rgba\(([\d.]+), ([\d.]+), ([\d.]+), ([\d.]+)\)/.exec(color);
    if (result) {
        const [, r, g, b, a] = result;
        const aVal = +a * 255;
        return [+r, +g, +b, isNaN(aVal) ? 255 : aVal];
    }
    return undefined;
};
export const DEFAULT_COLOR = [255, 255, 255, 255];
export const DEFAULT_RGBA_STRING = "rgba(255, 255, 255, 1)";
