import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import MUITab, { tabClasses as muiTabClasses } from "@mui/material/Tab";
import clsx from "clsx";
import { forwardRef } from "react";
import { mergeStyles, styled } from "../styles/index.js";
// MUST be the first export, since some of the exports are overridden below.
export * from "@mui/material/Tab";
const PREFIX = "GcxTab";
const gcxTabClasses = {
    endAdornment: `${PREFIX}-endAdornment`,
    fullWidthContainer: `${PREFIX}-fullWidthContainer`,
    tabAdorned: `${PREFIX}-tabAdorned`,
    tabContainer: `${PREFIX}-tabContainer`,
    /**
     * Styles applied to the label's wrapper element.
     */
    labelWrapper: `${PREFIX}-labelWrapper`,
};
export const tabClasses = {
    ...muiTabClasses,
    ...gcxTabClasses,
};
const Root = styled("div")({
    [`& .${gcxTabClasses.endAdornment}`]: {
        position: "absolute",
        top: "50%",
        transform: "translateY(-50%)",
        right: 2,
    },
    [`&.${gcxTabClasses.fullWidthContainer}`]: {
        display: "flex",
        // Copied from MUITab `fullWidth` styles
        flexShrink: 1,
        flexGrow: 1,
        flexBasis: 0,
        maxWidth: "none",
    },
    [`& .${gcxTabClasses.tabAdorned}`]: {
        paddingRight: 38,
    },
    [`&.${gcxTabClasses.tabContainer}`]: {
        position: "relative",
    },
    [`& .${gcxTabClasses.labelWrapper}`]: {
        whiteSpace: "nowrap",
        textOverflow: "ellipsis",
        overflow: "hidden",
        width: "100%",
    },
});
export * from "@mui/material/Tab";
const Tab = forwardRef((props, ref) => {
    const { className, classes, disabled, endAdornment, label, ...other } = props;
    const { endAdornment: endAdornmentClass, fullWidthContainer: fullWidthContainerClass, tabAdorned: tabAdornedClass, tabContainer: tabContainerClass, labelWrapper: labelWrapperClass, ...otherClasses } = mergeStyles(gcxTabClasses, classes);
    return (_jsxs(Root, { className: clsx(tabContainerClass, {
            [fullWidthContainerClass]: other["fullWidth"],
        }), children: [_jsx(MUITab, { className: clsx(className, {
                    [tabAdornedClass]: endAdornment,
                }), classes: otherClasses, disabled: disabled, ref: ref, tabIndex: disabled ? -1 : 0, label: label && _jsx("div", { className: labelWrapperClass, children: label }), ...other }), endAdornment && _jsx("div", { className: endAdornmentClass, children: endAdornment })] }));
});
export default Tab;
