import { jsx as _jsx } from "react/jsx-runtime";
import MUITabs, { tabsClasses as muiTabsClasses } from "@mui/material/Tabs";
import clsx from "clsx";
import { forwardRef } from "react";
import { mergeStyles, styled } from "../styles/index.js";
// MUST be the first export, since some of the exports are overridden below.
export * from "@mui/material/Tabs";
const PREFIX = "GcxTabs";
const gcxTabsClasses = {
    /**
     * Class applied when there is no indicator color.
     */
    indicatorTransparent: `${PREFIX}-indicatorTransparent`,
};
export const tabsClasses = {
    ...muiTabsClasses,
    ...gcxTabsClasses,
};
const StyledTabs = styled(MUITabs)({
    [`& .MuiTabs-indicator.${gcxTabsClasses.indicatorTransparent}`]: {
        backgroundColor: "transparent",
    },
});
const Tabs = forwardRef(({ classes, indicatorColor, ...props }, ref) => {
    const { indicator: indicatorClass, indicatorTransparent: indicatorTransparentClass, ...otherClasses } = mergeStyles(gcxTabsClasses, classes);
    return (_jsx(StyledTabs, { indicatorColor: indicatorColor, ...props, classes: {
            indicator: clsx(indicatorClass, {
                [indicatorTransparentClass]: !indicatorColor,
            }),
            ...otherClasses,
        }, ref: ref }));
});
export default Tabs;
