/**
 * Formats a date for display. The time portion will not appear in the output.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the date is formatted.
 */
export declare function formatDate(date: Date | undefined, options?: Intl.DateTimeFormatOptions, locale?: string): string;
/**
 * Formats a time for display. The date portion will not appear in the output.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the time is formatted.
 */
export declare function formatTime(date: Date | undefined, options?: Intl.DateTimeFormatOptions, locale?: string): string;
/**
 * Formats a date and time for display.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the date & time are
 *   formatted.
 */
export declare function formatDateTime(date: Date | undefined, options?: Intl.DateTimeFormatOptions, locale?: string): string;
/**
 * Formats a number for display.
 *
 * @param number The number to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the number is formatted.
 */
export declare function formatNumber(number: number | undefined, options?: Intl.NumberFormatOptions, locale?: string): string;
