// NOTE: If the browser's native Intl functions aren't given an explicit locale
// argument, then the format is "implementation dependent". In Chrome for
// instance it will use en-US formatting in this case even when both the browser
// and the OS are configured to use en-CA. For this reason, it's best practice
// to always specify the locale explicitly to get consistent and correct
// results, which is why `navigator.language` is used throughout these
// functions.
/**
 * Formats a date for display. The time portion will not appear in the output.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the date is formatted.
 */
export function formatDate(date, options, locale = navigator.language) {
    return date ? date.toLocaleDateString(locale, options) : "";
}
/**
 * Formats a time for display. The date portion will not appear in the output.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the time is formatted.
 */
export function formatTime(date, options, locale = navigator.language) {
    return date ? date.toLocaleTimeString(locale, options) : "";
}
/**
 * Formats a date and time for display.
 *
 * @param date The Date value to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the date & time are
 *   formatted.
 */
export function formatDateTime(date, options, locale = navigator.language) {
    return date ? date.toLocaleString(locale, options) : "";
}
/**
 * Formats a number for display.
 *
 * @param number The number to format.
 * @param locale An optional locale to use. If not specified, the browser's
 *   locale will be used.
 * @param options Additional options that control how the number is formatted.
 */
export function formatNumber(number, options, locale = navigator.language) {
    return typeof number === "number" ? number.toLocaleString(locale, options) : "";
}
