/**
 * Throttles a function so it can only be fired once per given period of
 * milliseconds. If the function is called during the throttling period, the
 * last instance of the function being called will be run once the throttling
 * period ends. The callback is always invoked asynchronously.
 *
 * @param func The function to be throttled.
 * @param msBetweenRequests The minimum time between requests.
 */
export declare function throttle<T extends unknown[]>(func: (...args: [...T]) => void | Promise<void>, msBetweenRequests: number): (...args: [...T]) => void | Promise<void>;
/**
 * Same as `throttle()`, but optimized for animation and rendering.
 *
 * @param func The function to throttle.
 */
export declare function throttleAnimation<T extends unknown[]>(func: (...args: [...T]) => void | Promise<void>): (...args: [...T]) => void | Promise<void>;
