/**
 * Clears the hash string.
 */
export function clearHashParams() {
    history.replaceState(null, document.title, getUrlWithoutHash());
}
/**
 * Returns the decoded hash parameter value for a given key.
 *
 * @param key The key used to return a value.
 */
export function getHashParam(key) {
    return getKeyValuePairs()[key];
}
export function getQueryStringParam(key) {
    const params = new URL(window.location.href).searchParams;
    const value = params.get(key);
    // Prefer undefined over null
    return typeof value === "string" ? value : undefined;
}
/**
 * Returns the hash string.
 */
function getHashParamString() {
    return location.hash.substring(1);
}
/**
 * Returns an object with hash parameters as key/value pairs.
 */
function getKeyValuePairs() {
    const kvp = {};
    if (hasHashParams()) {
        const params = getHashParamString().split("&");
        for (const param of params) {
            const keyPair = param.split("=");
            kvp[decodeURIComponent(keyPair[0])] = decodeURIComponent(keyPair[1]);
        }
    }
    return kvp;
}
/**
 * Returns the URL without the hash string.
 */
function getUrlWithoutHash() {
    return `${location.protocol}//${location.host}${location.pathname}${location.search}`;
}
/**
 * Whether the window currently has a hash string.
 */
function hasHashParams() {
    return !!location.hash;
}
/**
 * Builds and sets the hash string.
 *
 * @param kvp An object with hash parameters as key/value pairs.
 */
export function setHashParams(kvp) {
    const hashParamList = [];
    for (const key of Object.keys(kvp)) {
        hashParamList.push(`${encodeURIComponent(key)}=${encodeURIComponent(kvp[key])}`);
    }
    const hashParamString = `#${hashParamList.join("&")}`;
    setHashParamsString(hashParamString);
}
/**
 * Sets the hash string.
 *
 * @param paramsString The string to be set as the hash string.
 */
function setHashParamsString(paramsString) {
    const pString = paramsString.startsWith("#") ? paramsString : `#${paramsString}`;
    history.replaceState(null, document.title, getUrlWithoutHash() + pString);
}
